Pmw.Blt reference manual
Description: Pmw - a toolkit for building high-level compound widgets in Python

# Pmw.Blt

### Name

  Pmw.Blt - interface to some BLT widgets and commands

### Description

  This module contains function interfaces to the BLT `busy` command as well as the classes Pmw.Blt.Vector, Pmw.Blt.Graph, Pmw.Blt.Stripchart and Pmw.Blt.Tabset, which are interfaces to the vector, graph, stripchart and tabset commands of version 2.4 of the BLT extension to Tk. The interfaces are complete except for Pmw.Blt.Vector where several creation options, methods and operations have not been implemented.

  The blt graph and barchart widgets are essentially the same and so only the graph widget has been ported. The `element_create()` method is not implememted for Pmw.Blt.Graph, so instead:

  - to create a line element, use the `line_create()` method and

  - to create a bar element, use the `bar_create()` method.

  To operate on elements, use the `element_*()` methods, such as `element_bind()`, `element_activate()`, etc.

  Note: Full documentation of Pmw.Blt.Graph is available in A User's Guide to Pmw.Blt written by Bjorn Ove Thue and Hans Petter Langtangen. You can also download the full HTML document of the guide for local viewing.

### Functions

  The following functions are available.

  Pmw.Blt.busy_forget(window)
    Interface to the BLT `busy forget` command.

  Pmw.Blt.busy_hold(window, cursor = None)
    Interface to the BLT `busy hold` command.

  Pmw.Blt.busy_release(window)
    Interface to the BLT `busy release` command.

  Pmw.Blt.haveblt(window)
    Return true if any commands in the BLT extension are available.

  Pmw.Blt.havebltbusy(window)
    Return true if the BLT busy command is available.

  Pmw.Blt.vector_expr(expression)
    Interface to the BLT `vector expr` command.

  Pmw.Blt.vector_names(pattern = None)
    Interface to the BLT `vector names` command.

Pmw 2.1 - 31 Dec 2020 - Home
Manual page last reviewed: 25 May 2002